==> hubzero-cms-2.1.0_2.1.12.0-1+deb8.tar.gz: source/cms/core/plugins/projects/feed/views/activity/tmpl/default.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

// No direct access
defined('_HZEXEC_') or die();

if (count($this->activities) > 0 ) { ?>
	<div class="activity-items" id="activity-feed">
		<?php
		// get all sessions
		$online = array();
		$sessions = Hubzero\Session\Helper::getAllSessions(array(
			'guest'    => 0,
			'distinct' => 1
		));
		if ($sessions)
		{
			// see if any session matches our userid
			foreach ($sessions as $session)
			{
				$online[] = $session->userid;
			}
		}

		// Loop through activities
		foreach ($this->activities as $activity)
		{
			// Show activity
			$this->view('_activity')
				->set('option', $this->option)
				->set('model', $this->model)
				->set('activity', $activity)
				->set('uid', $this->uid)
				->set('online', $online)
				->display();
		}
		?>
	</div>
<?php } else { ?>
	<p class="noresults"><?php echo Lang::txt('PLG_PROJECTS_BLOG_NO_ACTIVITIES'); ?></p>
<?php } ?>

<div id="more-updates" class="nav_pager">
	<?php
	if ($this->total > $this->filters['limit'])
	{
		$limit = $this->filters['limit'] + $this->limit;
		?>
		<p><a href="<?php echo Route::url($this->model->link() . '&active=feed&limit=' . $limit . '&prev=' . $this->filters['limit']);  ?>"><?php echo Lang::txt('PLG_PROJECTS_BLOG_VIEW_OLDER_ENTRIES'); ?></a></p>
	<?php } else if ($this->filters['limit'] != $this->limit) { ?>
		<p><?php echo Lang::txt('PLG_PROJECTS_BLOG_VIEW_OLDER_ENTRIES_NO_MORE'); ?></p>
	<?php } else if ($this->total > 5 && $this->total < $this->filters['limit']) { ?>
		<p><?php echo Lang::txt('PLG_PROJECTS_BLOG_VIEW_OLDER_ENTRIES_NO_MORE'); ?></p>
		<?php
	}
	?>
</div><!-- / #more-updates -->

==> hubzero-cms-2.2.0_2.2.6.0-1+deb8.tar.gz: source/cms/core/plugins/projects/feed/views/activity/tmpl/default.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

// No direct access
defined('_HZEXEC_') or die();

if (count($this->activities) > 0) { ?>
	<div class="activity-items" id="activity-feed">
		<?php
		// get all sessions
		$online = array();
		$sessions = Hubzero\Session\Helper::getAllSessions(array(
			'guest'    => 0,
			'distinct' => 1
		));
		if ($sessions)
		{
			// see if any session matches our userid
			foreach ($sessions as $session)
			{
				$online[] = $session->userid;
			}
		}

		// Loop through activities
		foreach ($this->activities as $activity)
		{
			// Show activity
			$this->view('_activity')
				->set('option', $this->option)
				->set('model', $this->model)
				->set('activity', $activity)
				->set('online', $online)
				->display();
		}
		?>
	</div>
<?php } else { ?>
	<p class="noresults"><?php echo Lang::txt('PLG_PROJECTS_BLOG_NO_ACTIVITIES'); ?></p>
<?php } ?>

<div id="more-updates" class="nav_pager">
	<?php
	$limit = $this->filters['limit'] + $this->limit;
	$start = $this->filters['limit'] + $this->filters['start'];

	if ($this->total > $start)
	{
		?>
		<p><a href="<?php echo Route::url($this->model->link('feed') . '&limit=' . $limit);  ?>"><?php echo Lang::txt('PLG_PROJECTS_BLOG_VIEW_OLDER_ENTRIES'); ?></a></p>
		<?php
	}
	else
	{
		?>
		<p><?php echo Lang::txt('PLG_PROJECTS_BLOG_VIEW_OLDER_ENTRIES_NO_MORE'); ?></p>
		<?php
	}
	?>
</div><!-- / #more-updates -->
